# API

Full API docs are linked below. Some key points of interest are:

- [Device](#pvi.device.Device)
- Device Components
  - [DeviceRef](#pvi.device.DeviceRef)
  - [SignalR](#pvi.device.SignalR)
  - [SignalW](#pvi.device.SignalW)
  - [SignalRW](#pvi.device.SignalRW)
  - [SignalX](#pvi.device.SignalX)
  - [SignalRef](#pvi.device.SignalRef)
  - [Group](#pvi.device.Group)
- Signal Widgets
  - [ButtonPanel](#pvi.device.ButtonPanel)
  - [ComboBox](#pvi.device.ComboBox)
  - [LED](#pvi.device.LED)
  - [SubScreen](#pvi.device.SubScreen)
  - [TextRead](#pvi.device.TextRead)
  - [TextWrite](#pvi.device.TextWrite)
- UI Formatting
   - [Formatter](#pvi._format.base.Formatter)
   - [UITemplate](#pvi._format.widget.UITemplate)
   - [BobTemplate](#pvi._format.bob.BobTemplate)
   - [WidgetFormatter](#pvi._format.widget.WidgetFormatter)
   - [Bounds](#pvi._format.utils.Bounds)


## Full Reference API

To browse the full generated reference API:

```{eval-rst}
.. toctree::
   :maxdepth: 1

   _api/index
```
